@@ -15,10 +15,24 @@ class SecretRoleTable(NetBoxTable):
         url_params={'role_id': 'pk'},
         verbose_name='Secrets',
     )
+    comments = columns.MarkdownColumn()
+    tags = columns.TagColumn(url_name='plugins:netbox_secrets:secretrole_list')
 
     class Meta(NetBoxTable.Meta):
         model = SecretRole
-        fields = ('pk', 'id', 'name', 'secret_count', 'description', 'slug', 'actions')
+        fields = (
+            'pk',
+            'id',
+            'name',
+            'secret_count',
+            'description',
+            'slug',
+            'comments',
+            'tags',
+            'created',
+            'last_updated',
+            'actions',
+        )
         default_columns = ('id', 'name', 'secret_count', 'description', 'actions')
 
 
@@ -32,6 +46,7 @@ class SecretTable(NetBoxTable):
     assigned_object_type = columns.ContentTypeColumn(verbose_name='Object type')
     assigned_object = tables.Column(linkify=True, orderable=False, verbose_name='Object')
     role = tables.Column(linkify=True)
+    comments = columns.MarkdownColumn()
     tags = columns.TagColumn(url_name='plugins:netbox_secrets:secret_list')
 
     class Meta(NetBoxTable.Meta):
@@ -40,11 +55,22 @@ class SecretTable(NetBoxTable):
             'pk',
             'id',
             'name',
+            'description',
             'assigned_object_type',
             'assigned_object',
             'role',
+            'comments',
             'created',
             'last_updated',
             'tags',
         )
-        default_columns = ('pk', 'id', 'name', 'assigned_object_type', 'assigned_object', 'role', 'actions')
+        default_columns = (
+            'pk',
+            'id',
+            'name',
+            'description',
+            'assigned_object_type',
+            'assigned_object',
+            'role',
+            'actions',
+        )
